##############
How to Install
##############

From source
===========

``dust_extinction`` can be installed from the source code in the normal
python fashion after downloading it from the git repo::

    python setup.py install

Using pip
=========

``dust_extinction`` can be installed using pip::

    # from PyPI
    pip install dust_extinction

    # if you already have an older version installed
    pip install --upgrade dust_extinction

    # from the master trunk on the repository, considered developmental code
    pip install git+https://github.com/karllark/dust_extinction.git

Using conda
===========

``dust_extinction`` can be installed using conda via the conda-forge channel::

    conda config --add channels conda-forge
    conda install dust_extinction
